'use client'

import { useState } from 'react'
import { 
  FiHome, FiGrid, FiClipboard, FiUsers, 
  FiSettings, FiPieChart, FiLogOut, FiMenu,
  FiX, FiCoffee, FiList, FiPackage, FiHash, 
  FiCornerDownRight, FiDollarSign
} from 'react-icons/fi'
import Link from 'next/link'
import { useUser } from '@/contexts/UserContext'
import { useRouter } from 'next/navigation'

export default function Sidebar({ isOpen, setIsOpen }: { isOpen: boolean; setIsOpen: (isOpen: boolean) => void }) {
  const { user } = useUser()
  const [expandedItem, setExpandedItem] = useState<string | null>(null)
  const { logout } = useUser()
  const router = useRouter()

  const handleLogout = async () => {
    logout()
    router.push('/')
  }

  // Dinamik menü öğeleri
  const menuItems = [
    { icon: FiHome, label: 'Ana Sayfa', href: '/dashboard' },
    { icon: FiCoffee, label: 'Mutfak', href: '/dashboard/kitchen' },
    
    {
      icon: FiCornerDownRight,
      label: 'QR Siparişleri',
      href: '/dashboard/qr-orders'
    },
    // Sadece adminler için raporlar
    ...(user?.role === 'admin' ? [
      {
        icon: FiDollarSign,
        label: 'Masa Ödeme Kayıtları',
        href: '/dashboard/payments',
        adminOnly: true
      },
      { 
        icon: FiGrid, 
        label: 'Masa Yönetimi', 
        href: '#',
        subItems: [
          { label: 'Masa Listesi', href: '/dashboard/tables' },
          { label: 'Masa Ekle', href: '/dashboard/tables/add' }
        ]
      },
      {
        icon: FiList,
        label: 'Kategori Yönetimi',
        href: '#',
        subItems: [
          { label: 'Kategori Listesi', href: '/dashboard/categories' },
          { label: 'Kategori Ekle', href: '/dashboard/categories/add' }
        ]
      },
      {
        icon: FiPackage,
        label: 'Ürün Yönetimi',
        href: '#',
        subItems: [
          { label: 'Ürün Listesi', href: '/dashboard/products' },
          { label: 'Ürün Ekle', href: '/dashboard/products/add' }
        ]
      },
      {
        icon: FiHash,
        label: 'QR Yönetimi',
        href: '#',
        subItems: [
          { label: 'QR Oluştur', href: '/dashboard/qr/create' }
        ]
      },
      {
        icon: FiUsers,
        label: 'Personel Yönetimi',
        href: '#',
        subItems: [
          { label: 'Personel Listesi', href: '/dashboard/staff' },
          { label: 'Personel Ekle', href: '/dashboard/staff/add' }
        ]
      },
      { 
        icon: FiPieChart, 
        label: 'Raporlar', 
        href: '/dashboard/reports',
        adminOnly: true
      },
      {
        icon: FiSettings,
        label: 'Ayarlar',
        href: '/dashboard/settings',
        adminOnly: true
      },
      
    ] : []),
  
  ]

  return (
    <>
      {/* Overlay */}
      {isOpen && (
        <div
          onClick={() => setIsOpen(false)}
          className="fixed inset-0 bg-black/50 lg:hidden z-40"
        />
      )}

      {/* Sidebar */}
      <aside
        className={`fixed top-0 left-0 h-full w-72 bg-white dark:bg-slate-800 border-r border-slate-200 dark:border-slate-700 z-50 lg:z-0 transition-transform duration-300 lg:translate-x-0 ${
          isOpen ? 'translate-x-0' : '-translate-x-full'
        }`}
      >
        <div className="flex flex-col h-full">
          {/* Logo */}
          <div className="p-6 border-b border-slate-100 dark:border-slate-700">
            <div className="flex items-center space-x-3">
              <div className="bg-gradient-to-br from-fuchsia-500 to-purple-500 p-2 rounded-xl shadow-lg">
                <FiCoffee className="w-6 h-6 text-white" />
              </div>
              <span className="text-xl font-bold bg-clip-text text-transparent bg-gradient-to-r from-fuchsia-500 to-purple-500">
                CafePos
              </span>
            </div>
          </div>

          {/* Menu */}
          <nav className="flex-1 p-4 space-y-1 overflow-y-auto">
            {menuItems
              .filter(item => !item.adminOnly || user?.role === 'admin')
              .map((item) => (
                <div key={item.label}>
                  {item.subItems ? (
                    <>
                      <button
                        onClick={() => setExpandedItem(expandedItem === item.label ? null : item.label)}
                        className="flex items-center justify-between w-full px-4 py-3 rounded-xl text-slate-600 dark:text-slate-300 hover:bg-fuchsia-50 dark:hover:bg-slate-700/50 hover:text-fuchsia-500 transition-colors group"
                      >
                        <div className="flex items-center space-x-3">
                          <item.icon className="w-5 h-5 group-hover:text-fuchsia-500" />
                          <span>{item.label}</span>
                        </div>
                        <svg
                          className={`w-4 h-4 transition-transform ${
                            expandedItem === item.label ? 'rotate-180' : ''
                          }`}
                          fill="none"
                          stroke="currentColor"
                          viewBox="0 0 24 24"
                        >
                          <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M19 9l-7 7-7-7" />
                        </svg>
                      </button>
                      {expandedItem === item.label && (
                        <div className="mt-1 ml-4 space-y-1">
                          {item.subItems.map((subItem) => (
                            <Link
                              key={subItem.href}
                              href={subItem.href}
                              className="flex items-center px-4 py-2 text-sm text-slate-600 dark:text-slate-400 rounded-lg hover:bg-fuchsia-50 dark:hover:bg-slate-700/50 hover:text-fuchsia-500 transition-colors"
                            >
                              {subItem.label}
                            </Link>
                          ))}
                        </div>
                      )}
                    </>
                  ) : (
                    <Link
                      href={item.href}
                      className="flex items-center space-x-3 px-4 py-3 rounded-xl text-slate-600 dark:text-slate-300 hover:bg-fuchsia-50 dark:hover:bg-slate-700/50 hover:text-fuchsia-500 transition-colors group"
                    >
                      <item.icon className="w-5 h-5 group-hover:text-fuchsia-500" />
                      <span>{item.label}</span>
                    </Link>
                  )}
                </div>
              ))}
          </nav>

          {/* Alt Kısım */}
          <div className="p-4 border-t border-slate-100 dark:border-slate-700">
            <button 
              onClick={handleLogout}
              className="flex items-center space-x-3 w-full px-4 py-3 rounded-xl text-slate-600 dark:text-slate-300 hover:bg-red-50 dark:hover:bg-red-900/10 hover:text-red-500 transition-colors group"
            >
              <FiLogOut className="w-5 h-5 group-hover:text-red-500" />
              <span>Çıkış Yap</span>
            </button>
          </div>
        </div>
      </aside>
    </>
  )
} 